@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.14 08:00:00                  #
+# Updated Date: 2025.07.13 01:00:00                  #
 # ================================================== #
 
 from typing import Optional, List
@@ -137,11 +137,55 @@ class Render:
         elif name == RenderEvent.EXTRA_END:
             self.end_extra(meta, ctx)
 
+        elif name == RenderEvent.LIVE_APPEND:
+            self.append_live(meta, ctx, chunk, begin)
+        elif name == RenderEvent.LIVE_CLEAR:
+            self.clear_live(meta, ctx)
+
         elif name == RenderEvent.ACTION_REGEN_SUBMIT:
             self.on_reply_submit(ctx)
         elif name == RenderEvent.ACTION_EDIT_SUBMIT:
             self.on_edit_submit(ctx)
 
+        # kernel state changed
+        elif name in [
+            RenderEvent.STATE_IDLE,
+            RenderEvent.STATE_BUSY,
+            RenderEvent.STATE_ERROR,
+        ]:
+            meta = meta or self.window.core.ctx.get_current_meta()
+            self.on_state_changed(name, meta)
+
+    def on_state_changed(self, state: str, meta: Optional[CtxMeta] = None):
+        """
+        Handle state change event
+
+        :param state: State name
+        :param meta: Context meta
+        """
+        self.instance().state_changed(state, meta)
+
+    def append_live(self, meta: CtxMeta, ctx: CtxItem, text_chunk: str, begin: bool = False):
+        """
+        Append live text chunk to output
+
+        :param meta: context meta
+        :param ctx: context item
+        :param text_chunk: text chunk
+        :param begin: if it is the beginning of the stream
+        """
+        self.instance().append_live(meta, ctx, text_chunk, begin)
+        self.update()
+
+    def clear_live(self, meta: CtxMeta, ctx: CtxItem):
+        """
+        Clear live output
+
+        :param meta: context meta
+        :param ctx: context item
+        """
+        self.instance().clear_live(meta, ctx)
+        self.update()
 
     def get_pid(self, meta: CtxMeta) -> int:
         """
@@ -565,11 +609,13 @@ class Render:
         plain = self.window.core.config.get('render.plain')
         if plain:
             self.window.controller.theme.markdown.clear()
+            self.window.ui.nodes['output.timestamp'].setVisible(True)
             for pid in self.window.ui.nodes['output_plain']:
                 if self.window.ui.nodes['output_plain'][pid] is not None:
                     self.window.ui.nodes['output'][pid].setVisible(False)
                     self.window.ui.nodes['output_plain'][pid].setVisible(True)
         else:
+            self.window.ui.nodes['output.timestamp'].setVisible(False)
             self.window.controller.ctx.refresh()  # TODO: move to on_switch
             self.window.controller.theme.markdown.update(force=True)
             for pid in self.window.ui.nodes['output']:
