@@ -6,9 +6,12 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.05 23:00:00                  #
+# Updated Date: 2024.12.14 08:00:00                  #
 # ================================================== #
 
+from typing import Any, Optional
+
+
 class Confirm:
     def __init__(self, window=None):
         """
@@ -18,7 +21,12 @@ class Confirm:
         """
         self.window = window
 
-    def accept(self, type: str, id: any = None, parent_object=None):
+    def accept(
+            self,
+            type: str,
+            id: Optional[str] = None,
+            parent_object: Any = None
+    ):
         """
         Confirm dialog accept
 
@@ -59,6 +67,8 @@ class Confirm:
             self.window.controller.ctx.delete_group(id, True)  # group delete
         elif type == 'ctx.group.delete.all':
             self.window.controller.ctx.delete_group_all(id, True)  # group delete + items
+        elif type == 'ctx.reset_meta':
+            self.window.controller.ctx.common.reset(id, True)
 
         # images
         elif type == 'img_delete':
@@ -72,6 +82,10 @@ class Confirm:
         elif type == 'interpreter.clear':
             self.window.tools.get("interpreter").clear(force=True)
 
+        # html canvas
+        elif type == 'html_canvas.clear':
+            self.window.tools.get("html_canvas").clear(force=True)
+
         # audio transcribe
         elif type == 'audio.transcribe':
             self.window.tools.get("transcriber").transcribe(id, force=True)
@@ -129,6 +143,10 @@ class Confirm:
             self.window.controller.assistant.files.delete(id, True)
         elif type == 'attachments.clear':
             self.window.controller.attachment.clear(force=True, remove_local=True)
+        elif type == 'attachments.ctx.clear':
+            self.window.controller.chat.attachment.clear(force=True, remove_local=True)
+        elif type == 'attachments.ctx.delete':
+            self.window.controller.chat.attachment.delete_by_idx(id, force=True, remove_local=True)
 
         # files
         elif type == 'files.delete':
@@ -144,7 +162,7 @@ class Confirm:
 
         # tab close all
         elif type == 'tab.close_all':
-            self.window.controller.ui.tabs.close_all(id, True)  # by type
+            self.window.controller.ui.tabs.close_all(id, 0, True)  # by type
 
         # editor
         elif type == 'editor.changed.clear':
@@ -254,7 +272,11 @@ class Confirm:
         elif type == 'prompt.custom.delete':
             self.window.controller.presets.delete_prompt(id, True)
 
-    def dismiss(self, type: str, id: any):
+    def dismiss(
+            self,
+            type: str,
+            id: Any
+    ):
         """
         Confirm dialog dismiss
 
@@ -273,7 +295,12 @@ class Confirm:
 
         self.window.ui.dialog['confirm'].close()
 
-    def accept_rename(self, type: str, id: any, name: str):
+    def accept_rename(
+            self,
+            type: str,
+            id: Any,
+            name: str
+    ):
         """
         Update name of object
 
@@ -315,7 +342,12 @@ class Confirm:
         elif type == 'prompt.custom.new':
             self.window.controller.presets.save_prompt(name, True)
 
-    def accept_create(self, type: str, id: any, name: str):
+    def accept_create(
+            self,
+            type: str,
+            id: any,
+            name: str
+    ):
         """
         Create new object
 
@@ -339,6 +371,23 @@ class Confirm:
         elif type == 'ctx.group':
             self.window.controller.ctx.create_group(name, id)
 
+    def accept_url(
+            self,
+            type: str,
+            id: any,
+            url: str
+    ):
+        """
+        Update URL provided
+
+        :param type: dialog type
+        :param id: dialog object id
+        :param url: URL
+        """
+        # add attachment
+        if type == 'attachment':
+            self.window.controller.attachment.add_url(url)
+
     def dismiss_rename(self):
         """Dismiss rename dialog"""
         self.window.ui.dialog['rename'].close()
@@ -346,3 +395,7 @@ class Confirm:
     def dismiss_create(self):
         """Dismiss create dialog"""
         self.window.ui.dialog['create'].close()
+
+    def dismiss_url(self):
+        """Dismiss url dialog"""
+        self.window.ui.dialog['url'].close()
