@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.12.16 01:00:00                  #
+# Updated Date: 2025.07.13 01:00:00                  #
 # ================================================== #
 
 import copy
@@ -21,6 +21,7 @@ from llama_index.core import Document
 
 from pygpt_net.core.bridge import BridgeContext
 from pygpt_net.core.events import KernelEvent
+from pygpt_net.core.types import MODEL_DEFAULT_MINI
 from pygpt_net.item.attachment import AttachmentItem
 from pygpt_net.item.ctx import CtxMeta, CtxItem
 
@@ -535,9 +536,9 @@ class Context:
         model_item = None
         model = None
         if mode == "summary":
-            model = self.window.core.config.get("ctx.attachment.summary.model", "gpt-4o-mini")
+            model = self.window.core.config.get("ctx.attachment.summary.model", MODEL_DEFAULT_MINI)
         elif mode == "query":
-            model = self.window.core.config.get("ctx.attachment.query.model", "gpt-4o-mini")
+            model = self.window.core.config.get("ctx.attachment.query.model", MODEL_DEFAULT_MINI)
         if model:
             model_item = self.window.core.models.get(model)
         return model, model_item
