@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.07.09 22:00:00                  #
+# Updated Date: 2025.07.13 01:00:00                  #
 # ================================================== #
 
 import copy
@@ -23,6 +23,7 @@ from pygpt_net.core.types import (
     MULTIMODAL_IMAGE,
     MULTIMODAL_AUDIO,
     MULTIMODAL_VIDEO,
+    MODEL_DEFAULT_MINI,
 )
 from pygpt_net.item.model import ModelItem
 from pygpt_net.provider.core.model.json_file import JsonFileProvider
@@ -39,7 +40,7 @@ class Models:
         self.window = window
         self.provider = JsonFileProvider(window)
         self.ollama = Ollama(window)
-        self.default = "gpt-4o-mini"
+        self.default = MODEL_DEFAULT_MINI
         self.items = {}
         self.multimodal = [
             MULTIMODAL_TEXT,
