@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.06.21 16:00:00                  #
+# Updated Date: 2025.07.13 01:00:00                  #
 # ================================================== #
 
 import os
@@ -70,11 +70,58 @@ class Body:
         if syntax_style is None or syntax_style == "":
             syntax_style = "default"
         fonts_path = os.path.join(self.window.core.config.get_app_path(), "data", "fonts").replace("\\", "/")
-        stylesheet = self.window.controller.theme.markdown.get_web_css().replace('%fonts%', fonts_path)
+        # loader
+        stylesheet = """
+        .lds-ring {
+          /* change color here */
+          color: #1c4c5b
+        }
+        .lds-ring,
+        .lds-ring div {
+          box-sizing: border-box;
+        }
+        .lds-ring {
+          display: inline-block;
+          position: relative;
+          width: 80px;
+          height: 80px;
+        }
+        .lds-ring div {
+          box-sizing: border-box;
+          display: block;
+          position: absolute;
+          width: 64px;
+          height: 64px;
+          margin: 8px;
+          border: 8px solid currentColor;
+          border-radius: 50%;
+          animation: lds-ring 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;
+          border-color: currentColor transparent transparent transparent;
+        }
+        .lds-ring div:nth-child(1) {
+          animation-delay: -0.45s;
+        }
+        .lds-ring div:nth-child(2) {
+          animation-delay: -0.3s;
+        }
+        .lds-ring div:nth-child(3) {
+          animation-delay: -0.15s;
+        }
+        @keyframes lds-ring {
+          0% {
+            transform: rotate(0deg);
+          }
+          100% {
+            transform: rotate(360deg);
+          }
+        }
+        """
+        stylesheet += self.window.controller.theme.markdown.get_web_css().replace('%fonts%', fonts_path)
         if syntax_style in syntax_dark:
             stylesheet += "pre { color: #fff; }"
         else:
             stylesheet += "pre { color: #000; }"
+
         return stylesheet + " " + self.highlight.get_style_defs()
 
     def prepare_action_icons(
@@ -393,6 +440,7 @@ class Body:
         new QWebChannel(qt.webChannelTransport, function (channel) {
             bridge = channel.objects.bridge;
         });
+        var collapsed_idx = [];
         history.scrollRestoration = "manual";
         document.addEventListener('keydown', function(event) {
             if (event.ctrlKey && event.key === 'f') {
@@ -409,6 +457,9 @@ class Body:
                 window.location.href = 'bridge://focus';
             }
         });
+        function prepare() {        
+            collapsed_idx = [];  // clear collapsed code
+        }
         function sanitize(content) {
             var parser = new DOMParser();
             var doc = parser.parseFromString(content, "text/html");
@@ -424,7 +475,8 @@ class Body:
             document.querySelectorAll('pre code').forEach(el => {
                 if (!el.classList.contains('hljs')) hljs.highlightElement(el);
             });
-            renderMath();            
+            renderMath();         
+            restoreCollapsedCode();   
         }
         function renderMath() {
               const scripts = document.querySelectorAll('script[type^="math/tex"]');
@@ -670,6 +722,18 @@ class Body:
                 }
             }
         }
+        function replaceLive(content) {
+            const element = document.getElementById('_append_live_');
+            if (element) {
+                if (element.classList.contains('hidden')) {
+                    element.classList.remove('hidden');
+                    element.classList.add('visible');
+                }
+                element.innerHTML = sanitize(content);
+            }
+            highlightCode();
+            scrollToBottom();
+        }
         function updateFooter(content) {
             const element = document.getElementById('_footer_');
             if (element) {
@@ -696,6 +760,21 @@ class Body:
                 element.textContent = '';
             }
         }
+        function clearLive() {
+            const element = document.getElementById('_append_live_');
+            if (element) {
+                if (element.classList.contains('visible')) {
+                    element.classList.remove('visible');
+                    element.classList.add('hidden');
+                    // timeout to clear content
+                    setTimeout(function() {
+                        element.textContent = '';
+                    }, 1000);
+                } else {
+                    element.textContent = '';
+                }
+            }
+        }
         function enableEditIcons() {
             const container = document.body;
             if (container) {
@@ -741,11 +820,46 @@ class Body:
             }
             document.head.appendChild(style);
         }
+        function restoreCollapsedCode() {
+            const codeWrappers = document.querySelectorAll('.code-wrapper');
+            codeWrappers.forEach(function(wrapper) {
+                const index = wrapper.getAttribute('data-index');
+                const localeCollapse = wrapper.getAttribute('data-locale-collapse');
+                const localeExpand = wrapper.getAttribute('data-locale-expand');
+                const source = wrapper.querySelector('code');                
+                if (source && collapsed_idx.includes(index)) {
+                    source.style.display = 'none';
+                    const collapseBtn = wrapper.querySelector('.code-header-collapse');                    
+                    if (collapseBtn) {
+                        const collapseSpan = collapseBtn.querySelector('span');
+                        if (collapseSpan) {
+                            collapseSpan.textContent = localeExpand;
+                        }
+                        collapseBtn.classList.add('collapsed');
+                    }
+                } else if (source) {
+                    source.style.display = 'block';
+                    const collapseBtn = wrapper.querySelector('.code-header-collapse');
+                    if (collapseBtn) {
+                        const collapseSpan = collapseBtn.querySelector('span');
+                        if (collapseSpan) {
+                            collapseSpan.textContent = localeCollapse;
+                        }
+                        collapseBtn.classList.remove('collapsed');
+                    }
+                }
+            });
+        }
         function bridgeCopyCode(text) {
             if (bridge) {
                 bridge.copy_text(text);
             }
         }
+        function bridgePreviewCode(text) {
+            if (bridge) {
+                bridge.preview_text(text);
+            }
+        }
         function bridgeUpdateScrollPosition(pos) {
             if (bridge) {
                 bridge.update_scroll_position(pos);
@@ -758,6 +872,24 @@ class Body:
             window.scrollTo(0, pos);
             prevScroll = parseInt(pos);
         }  
+        function showLoading() {
+            const el = document.getElementById('_loader_');
+            if (el) {
+                if (el.classList.contains('hidden')) {
+                    el.classList.remove('hidden');
+                }
+                el.classList.add('visible');
+            }
+        }
+        function hideLoading() {
+            const el = document.getElementById('_loader_');
+            if (el) {
+                if (el.classList.contains('visible')) {
+                    el.classList.remove('visible');
+                }
+                el.classList.add('hidden');
+            }
+        }
         document.addEventListener('DOMContentLoaded', function() {
             const container = document.getElementById('container');
             function addClassToMsg(id, className) {
@@ -785,15 +917,71 @@ class Body:
                 }
             });
             container.addEventListener('click', function(event) {
-                if (event.target.classList.contains('code-header-copy')) {
+                // btn copy
+                const copyButton = event.target.closest('.code-header-copy');
+                if (copyButton) {
+                    event.preventDefault();
+                    const parent = event.target.closest('.code-wrapper');
+                    const source = parent.querySelector('code');
+                    const localeCopy = parent.getAttribute('data-locale-copy');
+                    const localeCopied = parent.getAttribute('data-locale-copied');
+                    if (source) {
+                        const text = source.textContent || source.innerText;
+                        bridgeCopyCode(text);
+                        const copySpan = copyButton.querySelector('span');
+                        if (copySpan) {
+                            copySpan.textContent = localeCopied;
+                            setTimeout(function() {
+                                copySpan.textContent = localeCopy;
+                            }, 1000);
+                        }
+                    }                        
+                }                
+                // btn preview
+                const previewButton = event.target.closest('.code-header-preview');
+                if (previewButton) {
                     event.preventDefault();
                     const parent = event.target.closest('.code-wrapper');
                     const source = parent.querySelector('code');
                     if (source) {
                         const text = source.textContent || source.innerText;
-                        bridgeCopyCode(text);
+                        bridgePreviewCode(text);
                     }                        
                 }
+                // btn collapse
+                const collapseButton = event.target.closest('.code-header-collapse');
+                if (collapseButton) {
+                    event.preventDefault();
+                    const parent = collapseButton.closest('.code-wrapper');
+                    const index = parent.getAttribute('data-index');
+                    const source = parent.querySelector('code');
+                    const localeCollapse = parent.getAttribute('data-locale-collapse');
+                    const localeExpand = parent.getAttribute('data-locale-expand');
+                    if (source) {
+                        if (source.style.display === 'none') {
+                            source.style.display = 'block';
+                            collapseButton.classList.remove('collapsed');
+                            const idx = collapsed_idx.indexOf(index);
+                            if (idx !== -1) {
+                                collapsed_idx.splice(idx, 1);
+                                const collapseSpan = collapseButton.querySelector('span');
+                                if (collapseSpan) {
+                                    collapseSpan.textContent = localeCollapse;
+                                }
+                            }
+                        } else {
+                            source.style.display = 'none';
+                            collapseButton.classList.add('collapsed');
+                            if (!collapsed_idx.includes(index)) {
+                                collapsed_idx.push(index);
+                                const collapseSpan = collapseButton.querySelector('span');
+                                if (collapseSpan) {
+                                    collapseSpan.textContent = localeExpand;
+                                }
+                            }
+                        }
+                    }
+                }
             });
         });
         </script>
@@ -802,8 +990,12 @@ class Body:
         <div id="container">
             <div id="_nodes_" class="nodes empty_list"></div>
             <div id="_append_input_" class="append_input"></div>
-            <div id="_append_output_" class="append_output"></div>
+            <div id="_append_output_" class="append_output"></div>            
+            <div id="_append_live_" class="append_live hidden"></div>
             <div id="_footer_" class="footer"></div>
+            <div id="_loader_" class="loader-global hidden">
+                <div class="lds-ring"><div></div><div></div><div></div><div></div></div>
+            </div>
         </div>
         </body>
         </html>
