@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.06.28 22:00:00                  #
+# Updated Date: 2025.07.13 01:00:00                  #
 # ================================================== #
 
 import json
@@ -27,6 +27,8 @@ from .helpers import Helpers
 from .parser import Parser
 from .pid import PidData
 
+from pygpt_net.core.events import RenderEvent
+
 
 class Renderer(BaseRenderer):
     NODE_INPUT = 0
@@ -60,6 +62,11 @@ class Renderer(BaseRenderer):
         node = self.get_output_node(meta)
         node.set_meta(meta)
         self.reset(meta)
+        self.parser.reset()
+        try:
+            node.page().runJavaScript(f"if (typeof window.prepare !== 'undefined') prepare();")
+        except Exception as e:
+            pass
 
     def on_page_loaded(
             self,
@@ -131,6 +138,42 @@ class Renderer(BaseRenderer):
         else:
             self.clear_chunks(pid)
 
+    def state_changed(
+            self,
+            state: str,
+            meta: CtxMeta,
+    ):
+        """
+        On kernel state changed event
+
+        :param state: state name
+        :param meta: context meta
+        """
+        # BUSY: current pid only
+        if state == RenderEvent.STATE_BUSY:
+            if meta:
+                pid = self.get_pid(meta)
+                if pid is not None:
+                    node = self.get_output_node_by_pid(pid)
+                    node.page().runJavaScript(
+                        f"if (typeof window.showLoading !== 'undefined') showLoading();")
+
+        # IDLE: all pids
+        elif state == RenderEvent.STATE_IDLE:
+            for pid in self.pids:
+                node = self.get_output_node_by_pid(pid)
+                if node is not None:
+                    node.page().runJavaScript(
+                        f"if (typeof window.hideLoading !== 'undefined') hideLoading();")
+
+        # ERROR: all pids
+        elif state == RenderEvent.STATE_ERROR:
+            for pid in self.pids:
+                node = self.get_output_node_by_pid(pid)
+                if node is not None:
+                    node.page().runJavaScript(
+                        f"if (typeof window.hideLoading !== 'undefined') hideLoading();")
+
     def begin(
             self,
             meta: CtxMeta,
@@ -427,6 +470,85 @@ class Renderer(BaseRenderer):
         except Exception as e:
             pass
 
+    def append_live(
+            self,
+            meta: CtxMeta,
+            ctx: CtxItem,
+            text_chunk: str,
+            begin: bool = False
+    ):
+        """
+        Append live output chunk to output
+
+        :param meta: context meta
+        :param ctx: context item
+        :param text_chunk: text chunk
+        :param begin: if it is the beginning of the text
+        """
+        pid = self.get_or_create_pid(meta)
+        self.pids[pid].item = ctx
+        if text_chunk is None or text_chunk == "":
+            if begin:
+                self.pids[pid].live_buffer = ""  # always reset buffer
+            return
+        self.update_names(meta, ctx)
+        raw_chunk = str(text_chunk)
+        raw_chunk = raw_chunk.replace("<", "&lt;")
+        raw_chunk = raw_chunk.replace(">", "&gt;")
+        if begin:
+            # debug
+            debug = ""
+            if self.is_debug():
+                debug = self.append_debug(ctx, pid, "stream")
+            if debug:
+                raw_chunk = debug + raw_chunk
+            self.pids[pid].live_buffer = ""  # reset buffer
+            self.pids[pid].is_cmd = False  # reset command flag
+            self.clear_live(meta, ctx)  # clear live output
+        self.pids[pid].live_buffer += raw_chunk
+
+        """
+        # cooldown (throttling) to prevent high CPU usage on huge text chunks
+        if len(self.buffer) > self.throttling_min_chars:
+            current_time = time.time()
+            if current_time - self.last_time_called <= self.cooldown:
+                return  # wait a moment
+            else:
+                self.last_time_called = current_time
+        """
+
+        # parse chunks
+        to_append = self.pids[pid].live_buffer
+        if has_unclosed_code_tag(self.pids[pid].live_buffer):
+            to_append += "\n```"  # fix for code block without closing ```
+        html = self.parser.parse(to_append)
+        escaped_chunk = json.dumps(html)
+        try:
+            self.get_output_node(meta).page().runJavaScript(
+                f"replaceLive({escaped_chunk});")
+        except Exception as e:
+            pass
+
+    def clear_live(self, meta: CtxMeta, ctx: CtxItem):
+        """
+        Clear live output
+
+        :param meta: context meta
+        :param ctx: context item
+        """
+        if meta is None:
+            return
+        pid = self.get_or_create_pid(meta)
+        if not self.pids[pid].loaded:
+            js = "var element = document.getElementById('_append_live_');"
+            js += "if (element) { element.innerHTML = ''; }"
+        else:
+            js = "clearLive();"
+        try:
+            self.get_output_node_by_pid(pid).page().runJavaScript(js)
+        except Exception as e:
+            pass
+
     def append_node(
             self,
             meta: CtxMeta,
@@ -653,6 +775,9 @@ class Renderer(BaseRenderer):
                 pid = self.get_or_create_pid(meta)
                 self.reset_by_pid(pid)
 
+        # clear live output
+        self.clear_live(meta, CtxItem())
+
     def reset_by_pid(self, pid: Optional[int]):
         """
         Reset by PID
