@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2025.06.30 20:00:00                  #
+# Updated Date: 2025.07.09 22:00:00                  #
 # ================================================== #
 
 from typing import Optional, List, Dict
@@ -51,7 +51,7 @@ class GoogleLLM(BaseLLM):
         :param stream: stream mode
         :return: LLM provider instance
         """
-        args = self.parse_args(model.llama_index)
+        args = self.parse_args(model.llama_index, window)
         if "model" not in args:
             args["model"] = model.id
         return GoogleGenAI(**args)
@@ -72,5 +72,5 @@ class GoogleLLM(BaseLLM):
         if config is not None:
             args = self.parse_args({
                 "args": config,
-            })
+            }, window)
         return GeminiEmbedding(**args)
