@@ -6,7 +6,7 @@
 # GitHub:  https://github.com/szczyglis-dev/py-gpt   #
 # MIT License                                        #
 # Created By  : Marcin Szczygliński                  #
-# Updated Date: 2024.11.18 21:00:00                  #
+# Updated Date: 2025.06.30 02:00:00                  #
 # ================================================== #
 
 from PySide6.QtCore import Qt
@@ -20,6 +20,7 @@ from pygpt_net.ui.widget.element.group import CollapsedGroup
 from pygpt_net.ui.widget.element.labels import UrlLabel, HelpLabel
 from pygpt_net.ui.widget.lists.plugin import PluginList
 from pygpt_net.ui.widget.option.checkbox import OptionCheckbox
+from pygpt_net.ui.widget.option.checkbox_list import OptionCheckboxList
 from pygpt_net.ui.widget.option.cmd import OptionCmd
 from pygpt_net.ui.widget.option.combo import OptionCombo
 from pygpt_net.ui.widget.option.dictionary import OptionDict
@@ -330,6 +331,9 @@ class Plugins:
                 widgets[key] = OptionTextarea(self.window, parent, key, option)  # textarea
             elif option['type'] == 'bool':
                 widgets[key] = OptionCheckbox(self.window, parent, key, option)  # checkbox
+            elif option['type'] == 'bool_list':
+                self.window.controller.config.placeholder.apply(option)
+                widgets[key] = OptionCheckboxList(self.window, parent, key, option)  # checkbox list
             elif option['type'] == 'dict':
                 self.window.controller.config.placeholder.apply(option)
                 widgets[key] = OptionDict(self.window, parent, key, option)  # dictionary
@@ -430,13 +434,13 @@ class Plugins:
             cols = QHBoxLayout()
 
             if option['type'] not in no_label_types:
-                cols.addWidget(self.window.ui.nodes[label_key])  # disable label in bool type
+                cols.addWidget(self.window.ui.nodes[label_key], 1)  # disable label in bool type
 
-            cols.addWidget(widget)
+            cols.addWidget(widget, 4)
 
             cols_widget = QWidget()
             cols_widget.setLayout(cols)
-            cols_widget.setMaximumHeight(90)
+            # cols_widget.setMaximumHeight(90)
 
             self.window.ui.nodes[desc_key] = QLabel(txt_desc)
             self.window.ui.nodes[desc_key].setWordWrap(True)
